import request from '@/utils/request'

// 查询【请填写功能名称】列表
export function listInfo(query) {
  return request({
    url: '/system/rescueInfo/list2',
    method: 'get',
    params: query
  })
}
export function moneyManagement(query) {
  return request({
    url: '/system/rescueInfo/moneyManagement',
    method: 'get',
    params: query
  })
}
export function moneyManagementData(query) {
  return request({
    url: '/system/rescueInfo/moneyManagementData',
    method: 'get',
    params: query
  })
}


export function routeInfo(id) {
  return request({
    url: '/rescue/rescue_driver_position/routeInfo?rescueInfoId=' + id,
    method: 'get'
  })
}

// 查询【请填写功能名称】详细
export function getInfo(id) {
  return request({
    url: '/system/info/' + id,
    method: 'get'
  })
}
export function watchImg(id) {
  return request({
    url: '/system/rescueInfo/watchImg?rescueId=' + id,
    method: 'get'
  })
}

// 新增【请填写功能名称】
export function addInfo(data) {
  return request({
    url: '/system/info',
    method: 'post',
    data: data
  })
}

// 修改【请填写功能名称】
export function updateInfo(data) {
  return request({
    url: '/system/rescueInfo/update',
    method: 'post',
    data: data
  })
}

// 删除【请填写功能名称】
export function delInfo(id) {
  return request({
    url: '/system/rescueInfo/' + id,
    method: 'delete'
  })
}

export function getDriver() {
  return request({
    url: '/app/rescueInfo/driverList',
    method: 'get'
  })
}

export function designateDriver(rescueId,driverId) {
  return request({
    url: '/system/rescueInfo/designateDriver?rescueId='+rescueId+'&driverId='+driverId,
    method: 'post'
  })
}
export function returnOrder(data) {
  return request({
    url: '/system/rescueOrderReturn',
    method: 'post',
    data:data
  })
}

export function downloadOrder(params) {
  return request({
    url: '/system/rescueInfo/export',
    method: 'get',
    params,
    responseType: 'blob'
  })
}

export function exportManagement(params) {
  return request({
    url: '/system/rescueInfo/exportManagement',
    method: 'get',
    params,
    responseType: 'blob'
  })
}

export function listBuckle() {
  return request({
    url: "/system/rescueInfo/buckle",
    method:"get"
  })
}

export function getBuckle(id) {
  return request({
    url: "/system/rescueInfo/buckle/" + id,
    method:"get"
  })
}

export function returnCar(data){
  return request({
    url: '/system/rescueInfo/returnCar',
    method: 'post',
    data
  })
}

